from setuptools import setup

setup(
    name="bsci_email_library",
    version="0.0.1",
    description="This package does nothing.",
    long_description="This package is reserved and does nothing.",
    long_description_content_type="text/plain",
    packages=["bsci_email_library"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)